@@ -211,7 +211,14 @@ class ModelManagerClient(BaseClientWithSession):
 
         def polling_function():
             self.log.info("Polling for status of job '%s'", job_id)
-            return self.read_job_by_id(job_id)
+            job_resource = self.read_job_by_id(job_id)
+            self.log.info(
+                "Job '%s': status '%s', progress: '%s'",
+                job_id,
+                job_resource["status"],
+                job_resource["progress"],
+            )
+            return job_resource
 
         self.log.info("Waiting for job '%s' to finish.", job_id)
 
@@ -226,10 +233,12 @@ class ModelManagerClient(BaseClientWithSession):
             self.log.exception(timeout_msg)
             raise TrainingJobTimeOut(timeout_msg)
 
+        msg = "Job '{}' has status: '{}'".format(job_id, result["status"])
         if self.is_job_failed(result):
-            fail_msg = "Job '{}' has status: '{}'".format(job_id, result["status"])
-            self.log.error(fail_msg)
-            raise TrainingJobFailed(fail_msg)
+            self.log.error(msg)
+            raise TrainingJobFailed(msg)
+
+        self.log.info(msg)
 
         return result
 
@@ -444,13 +453,13 @@ class ModelManagerClient(BaseClientWithSession):
             self.log.exception(msg)
             raise DeploymentTimeOut(msg) from exc
 
+        msg = "Deployment '{}' has status: {}".format(deployment_id, response["status"])
         if self.is_deployment_failed(response):
-            msg = "Deployment '{}' has status: {}".format(
-                deployment_id, response["status"]
-            )
             self.log.error(msg)
             raise DeploymentFailed(msg)
 
+        self.log.info(msg)
+
         return response
 
     def deploy_and_wait(self, model_name: str) -> dict:
